enrichr_terms: Enrichr gene sets

Description Usage Format Details Source

Description

A dataset containing all gene sets from the Enrichr database including metadata. Release 2019-01-23.

Usage

1

Format

A tibble with 123 rows and 10 columns

library

the library or source the gene sets where derived from

year

release year of the library

n_terms

number of terms (gene sets)

gene_coverage

number of unique genes across all terms

n_genes_per_term

average number of genes per term

category

broad category for the gene set library

description

description of the membership in the gene set

data

list column containing the symbols for each term

Details

Where multiple versions are available, only the most recent release is included.

Please acknowledge Enrichr in your publications by citing the following references:

Chen EY, Tan CM, Kou Y, Duan Q, Wang Z, Meirelles GV, Clark NR, Ma'ayan A. Enrichr: interactive and collaborative HTML5 gene list enrichment analysis tool. BMC Bioinformatics. 2013;128(14)

Kuleshov MV, Jones MR, Rouillard AD, Fernandez NF, Duan Q, Wang Z, Koplev S, Jenkins SL, Jagodnik KM, Lachmann A, McDermott MG, Monteiro CD, Gundersen GW, Ma'ayan A. Enrichr: a comprehensive gene set enrichment analysis web server 2016 update. Nucleic Acids Research. 2016; gkw377

http://amp.pharm.mssm.edu/Enrichr/


clemenshug/enrichr.db documentation built on July 23, 2019, 8:08 a.m.